describe('ContainerDecoratorLayout', function(){
    var containerDecoratorLayout;
    var container;
    var expectedOriginalLayout;

    beforeEach(function(){
        container = {
            id: 'containerId',
            name: 'container',
            widgets: [{
                id: 'widgetId1',
                name: 'firstWidget',
                fields: [{
                    id: 'fieldId11',
                    name: 'firstField',
                    anotherProperty: 123,
                }, {
                    id: 'fieldId12',
                    name: 'secondField',
                    anotherProperty: 456,
                }],
            }, {
                id: 'widgetId2',
                name: 'secondWidget',
                widgets: [{
                    id: 'widgetId21',
                    name: 'firstWidget',
                    fields: [{
                        id: 'fieldId211',
                        name: 'firstField',
                        anotherProperty: 123,
                    }, {
                        id: 'fieldId212',
                        name: 'secondField',
                        anotherProperty: 456,
                    }],
                }],
            }],
        };
        expectedOriginalLayout = {
            widgetId1: {
                widgets: [{
                    id: 'widgetId1',
                    fields: [{
                        id: 'fieldId11',
                        name: 'firstField',
                        anotherProperty: 123
                    }, {
                        id: 'fieldId12',
                        name: 'secondField',
                        anotherProperty: 456
                    }],
                    widgets: []
                }, {
                    id: 'widgetId2',
                    widgets: [{
                        id: 'widgetId21',
                        widgets: []
                    }]
                }]
            },
            widgetId21: {
                widgets: [{
                    id: 'widgetId1',
                    widgets: []
                }, {
                    id: 'widgetId2',
                    widgets: [{
                        id: 'widgetId21',
                        fields: [{
                            id: 'fieldId211',
                            name: 'firstField',
                            anotherProperty: 123
                        }, {
                            id: 'fieldId212',
                            name: 'secondField',
                            anotherProperty: 456
                        }],
                        widgets: []
                    }]
                }]
            }
        };
        containerDecoratorLayout = new ContainerDecoratorLayout();
    });

    it('apply should return the container with ORIGINAL_LAYOUT property', function(){
        var newContainer = containerDecoratorLayout.apply(container.name, container);
        expect(newContainer.ORIGINAL_LAYOUT).toBeDefined();
        expect(newContainer.ORIGINAL_LAYOUT).toEqual(expectedOriginalLayout);
    });

    it('should register on ContainerDecoratorProvider', function(){
        var containerDecoratorMock = {
            registerProvider: function(){},
        };
        var registerProviderSpy = spyOn(containerDecoratorMock, 'registerProvider');
        var moduleToTest = angular.module('ZeedhiApp');
		var runMethod = moduleToTest._runBlocks[3];
        runMethod(containerDecoratorMock);
        expect(registerProviderSpy).toHaveBeenCalled();
    });
});